@@ -137,6 +137,7 @@ def get_posts(
     account: Optional[str] = None,
     group: Union[str, int, None] = None,
     post_urls: Optional[Iterator[str]] = None,
+    hashtag: Optional[str] = None,
     credentials: Optional[Credentials] = None,
     **kwargs,
 ) -> Iterator[Post]:
@@ -158,7 +159,7 @@ def get_posts(
     Yields:
         dict: The post representation in a dictionary.
     """
-    valid_args = sum(arg is not None for arg in (account, group, post_urls))
+    valid_args = sum(arg is not None for arg in (account, group, post_urls, hashtag))
 
     if valid_args != 1:
         raise ValueError("You need to specify either account, group, or post_urls")
@@ -202,6 +203,9 @@ def get_posts(
     elif group is not None:
         return _scraper.get_group_posts(group, **kwargs)
 
+    elif hashtag is not None:
+        return _scraper.get_posts_by_hashtag(hashtag, **kwargs)
+
     elif post_urls is not None:
         return _scraper.get_posts_by_url(post_urls, **kwargs)
 
@@ -368,6 +372,7 @@ def write_posts_to_csv(
     dump_location = kwargs.pop('dump_location', None)  # For dumping HTML to disk, for debugging
     if dump_location is not None:
         dump_location.mkdir(exist_ok=True)
+        kwargs["remove_source"] = False
 
     # Set a default filename, based on the account name with the appropriate extension
     if filename is None:
@@ -413,7 +418,6 @@ def write_posts_to_csv(
             group=group,
             start_url=start_url,
             request_url_callback=handle_pagination_url,
-            remove_source=not bool(dump_location),
             **kwargs,
         ):
             if dump_location is not None:
@@ -422,6 +426,8 @@ def write_posts_to_csv(
                     write_post_to_disk(post, source, dump_location)
                 except Exception:
                     logger.exception("Error writing post to disk")
+            elif post.get("source"):
+                post["source"] = post["source"].html
             if first_post:
                 if kwargs.get("format") == "json":
                     output_file.write("[\n")
