@@ -45,6 +45,12 @@ def extract_photo_post(
     return PhotoPostExtractor(raw_post, options, request_fn, full_post_html).extract_post()
 
 
+def extract_hashtag_post(
+    raw_post: RawPost, options: Options, request_fn: RequestFunction, full_post_html=None
+) -> Post:
+    return HashtagPostExtractor(raw_post, options, request_fn, full_post_html).extract_post()
+
+
 class PostExtractor:
     """Class for Extracting fields from a FacebookPost"""
 
@@ -188,6 +194,10 @@ class PostExtractor:
             except Exception as ex:
                 log_warning("Exception while running %s: %r", method.__name__, ex)
 
+        has_more = self.more_url_regex.search(self.element.html)
+        if has_more and self.full_post_html:
+            post['source'] = self.full_post_html.find('.story_body_container', first=True)
+
         if self.options.get('reactions') or self.options.get('reactors'):
             try:
                 reactions = self.extract_reactions()
@@ -229,7 +239,6 @@ class PostExtractor:
 
             except Exception as ex:
                 log_warning("Exception while extracting comments: %r", ex)
-
         return post
 
     def extract_post_id(self) -> PartialPost:
@@ -943,6 +952,9 @@ class PostExtractor:
             name = comment.find("h3", first=True).text
             commenter_id = None
             url = None
+            link = comment.find("h3>a", first=True)
+            if link:
+                url = utils.urljoin(FB_BASE_URL, link.attrs.get("href"))
         first_link = comment.find(
             "div:not([data-sigil])>a[href]:not([data-click]):not([data-store]):not([data-sigil])",
             first=True,
@@ -950,6 +962,8 @@ class PostExtractor:
         comment_body_elem = comment.find(
             '[data-sigil="comment-body"],div._14ye,div.bl', first=True
         )
+        if not comment_body_elem:
+            comment_body_elem = comment.find('div>div>div', first=True)
         if comment_body_elem:
             text = comment_body_elem.text
         else:
@@ -1059,14 +1073,14 @@ class PostExtractor:
         if not self.full_post_html:
             logger.error("Unable to get comments without full post HTML")
             return
-        comments_area_selector = 'div.ufi'
+        comments_area_selector = 'div[id^="ufi_"]'
         elem = self.full_post_html.find(comments_area_selector, first=True)
         if not elem:
             logger.error("No comments area found")
             return
         comments_selector = 'div[data-sigil="comment"]'
         if self.options.get("noscript"):
-            comments_selector = "div._55wr"
+            comments_selector = f"{comments_area_selector}>div>div:not(id)>div"
         comments = list(elem.find(comments_selector))
         if not comments:
             logger.warning("No comments found on page")
@@ -1282,3 +1296,21 @@ class PhotoPostExtractor(PostExtractor):
             match = re.search(r'ft_ent_identifier=(\d+)', self.full_post_html.html)
             if match:
                 return {"post_id": match.groups()[0]}
+
+
+class HashtagPostExtractor(PostExtractor):
+    def __init__(self, element, options, request_fn, full_post_html=None):
+        post_id = self.extract_hashtag_post_id(element)
+        if post_id:
+            response = request_fn(post_id)
+            if response:
+                element = response.html.find('[data-ft*="top_level_post_id"]')[0]
+                full_post_html = response.html
+
+        super().__init__(element, options, request_fn, full_post_html)
+
+    def extract_hashtag_post_id(self, element):
+        match = re.search(r'ft_ent_identifier=(\d+)', element.html)
+        if match:
+            return match.groups()[0]
+        return None
