@@ -19,9 +19,21 @@ from .constants import (
     FB_W3_BASE_URL,
     FB_MBASIC_BASE_URL,
 )
-from .extractors import extract_group_post, extract_post, extract_photo_post, PostExtractor
+from .extractors import (
+    extract_group_post,
+    extract_post,
+    extract_photo_post,
+    PostExtractor,
+    extract_hashtag_post,
+)
 from .fb_types import Post, Profile
-from .page_iterators import iter_group_pages, iter_pages, iter_photos, iter_search_pages
+from .page_iterators import (
+    iter_group_pages,
+    iter_pages,
+    iter_photos,
+    iter_search_pages,
+    iter_hashtag_pages,
+)
 from . import exceptions
 
 
@@ -76,7 +88,17 @@ class FacebookScraper:
         iter_pages_fn = partial(iter_photos, account=account, request_fn=self.get, **kwargs)
         return self._generic_get_posts(extract_post, iter_pages_fn, **kwargs)
 
+    def get_posts_by_hashtag(self, hashtag: str, **kwargs) -> Iterator[Post]:
+        kwargs["scraper"] = self
+        kwargs["base_url"] = FB_MBASIC_BASE_URL
+        iter_pages_fn = partial(
+            iter_hashtag_pages, hashtag=hashtag, request_fn=self.get, **kwargs
+        )
+        return self._generic_get_posts(extract_hashtag_post, iter_pages_fn, **kwargs)
+
     def get_posts_by_url(self, post_urls, options={}, remove_source=True) -> Iterator[Post]:
+        if self.session.cookies.get("noscript") == "1":
+            options["noscript"] = True
         for post_url in post_urls:
             url = str(post_url)
             if url.startswith(FB_BASE_URL):
@@ -85,24 +107,10 @@ class FacebookScraper:
                 url = url.replace(FB_W3_BASE_URL, FB_MOBILE_BASE_URL)
             if not url.startswith(FB_MOBILE_BASE_URL):
                 url = utils.urljoin(FB_MOBILE_BASE_URL, url)
+
             post = {"original_request_url": post_url, "post_url": url}
             logger.debug(f"Requesting page from: {url}")
             response = self.get(url)
-            if response.url == "https://m.facebook.com/watch/?ref=watch_permalink":
-                post_url = re.search("\d+", str(post_url)).group()
-                if post_url:
-                    url = utils.urljoin(
-                        FB_MOBILE_BASE_URL,
-                        f"story.php?story_fbid={post_url}&id=1&m_entstream_source=timeline",
-                    )
-                    post = {"original_request_url": post_url, "post_url": url}
-                    logger.debug(f"Requesting page from: {url}")
-                    response = self.get(url)
-            if "/watch/" in response.url:
-                video_id = parse_qs(urlparse(response.url).query).get("v")[0]
-                url = f"story.php?story_fbid={video_id}&id={video_id}&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
-                logger.debug(f"Fetching {url}")
-                response = self.get(url)
             options["response_url"] = response.url
             elem = response.html.find('[data-ft*="top_level_post_id"]', first=True)
             if not elem:
@@ -117,9 +125,12 @@ class FacebookScraper:
                 comments_area = response.html.find('div.ufi', first=True)
                 if comments_area:
                     # Makes likes/shares regexes work
-                    elem = utils.make_html_element(
-                        elem.html.replace("</footer>", comments_area.html + "</footer>")
-                    )
+                    try:
+                        elem = utils.make_html_element(
+                            elem.html.replace("</footer>", comments_area.html + "</footer>")
+                        )
+                    except ValueError as e:
+                        logger.debug(e)
 
                 if photo_post:
                     post.update(
@@ -684,10 +695,29 @@ class FacebookScraper:
         try:
             if not url.startswith("http"):
                 url = utils.urljoin(FB_MOBILE_BASE_URL, url)
+
             response = self.session.get(url=url, **self.requests_kwargs, **kwargs)
             response.html.html = response.html.html.replace('<!--', '').replace('-->', '')
             response.raise_for_status()
             self.check_locale(response)
+
+            # Special handling for video posts that redirect to /watch/
+            if response.url == "https://m.facebook.com/watch/?ref=watch_permalink":
+                post_url = re.search("\d+", url).group()
+                if post_url:
+                    url = utils.urljoin(
+                        FB_MOBILE_BASE_URL,
+                        f"story.php?story_fbid={post_url}&id=1&m_entstream_source=timeline",
+                    )
+                    post = {"original_request_url": post_url, "post_url": url}
+                    logger.debug(f"Requesting page from: {url}")
+                    response = self.get(url)
+            if "/watch/" in response.url:
+                video_id = parse_qs(urlparse(response.url).query).get("v")[0]
+                url = f"story.php?story_fbid={video_id}&id={video_id}&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
+                logger.debug(f"Fetching {url}")
+                response = self.get(url)
+
             if "cookie/consent-page" in response.url:
                 response = self.submit_form(response)
             if (
@@ -750,6 +780,11 @@ class FacebookScraper:
 
     def login(self, email: str, password: str):
         response = self.get(self.base_url)
+
+        cookies_values = re.findall(r'js_datr","([^"]+)', response.html.html)
+        if len(cookies_values) == 1:
+            self.session.cookies.set("datr", cookies_values[0])
+
         response = self.submit_form(
             response, {"email": email, "pass": password, "_fb_noscript": None}
         )
@@ -799,9 +834,10 @@ class FacebookScraper:
         page_limit=DEFAULT_PAGE_LIMIT,
         options=None,
         remove_source=True,
+        latest_date=None,
+        max_past_limit=5,
         **kwargs,
     ):
-        counter = itertools.count(0) if page_limit is None else range(page_limit)
 
         if options is None:
             options = {}
@@ -817,11 +853,90 @@ class FacebookScraper:
                 stacklevel=3,
             )
 
-        logger.debug("Starting to iterate pages")
-        for i, page in zip(counter, iter_pages_fn()):
-            logger.debug("Extracting posts from page %s", i)
-            for post_element in page:
-                post = extract_post_fn(post_element, options=options, request_fn=self.get)
-                if remove_source:
-                    post.pop('source', None)
-                yield post
+        # if latest_date is specified, iterate until the date is reached n times in a row (recurrent_past_posts)
+        if latest_date is not None:
+
+            # Pinned posts repeat themselves over time, so ignore them
+            pinned_posts = []
+
+            # Stats
+            null_date_posts = 0
+            total_scraped_posts = 0
+
+            # Helpers
+            recurrent_past_posts = 0
+            show_every = 50
+            done = False
+
+            for page in iter_pages_fn():
+
+                for post_element in page:
+                    try:
+                        post = extract_post_fn(post_element, options=options, request_fn=self.get)
+
+                        if remove_source:
+                            post.pop("source", None)
+
+                        # date is None, no way to check latest_date, yield it
+                        if post["time"] is None:
+                            null_date_posts += 1
+
+                        # date is above latest_date, yield it
+                        if post["time"] > latest_date:
+                            recurrent_past_posts = 0
+
+                        # if any of above, yield the post and continue
+                        if post["time"] is None or post["time"] > latest_date:
+                            total_scraped_posts += 1
+                            if total_scraped_posts % show_every == 0:
+                                logger.info("Posts scraped: %s", total_scraped_posts)
+
+                            yield post
+                            continue
+
+                        # else, the date is behind the date limit
+                        recurrent_past_posts += 1
+
+                        # and it has reached the max_past_limit posts
+                        if recurrent_past_posts >= max_past_limit:
+                            done = True
+                            logger.info(
+                                "Sequential posts behind latest_date reached. Stopping scraping."
+                            )
+                            logger.info(
+                                "Posts with null date: %s",
+                                null_date_posts,
+                            )
+                            break
+
+                        # or the text is not banned (repeated)
+                        if post["text"] is not None and post["text"] not in pinned_posts:
+                            pinned_posts.append(post["text"])
+                            logger.warning(
+                                "Sequential post #%s behind the date limit: %s. Ignored (in logs) from now on.",
+                                recurrent_past_posts,
+                                post["time"],
+                            )
+
+                    except Exception as e:
+                        logger.exception(
+                            "An exception has occured during scraping: %s. Omitting the post...",
+                            e,
+                        )
+
+                # if max_past_limit, stop
+                if done:
+                    break
+
+        # else, iterate over pages as usual
+        else:
+            counter = itertools.count(0) if page_limit is None else range(page_limit)
+
+            logger.debug("Starting to iterate pages")
+            for i, page in zip(counter, iter_pages_fn()):
+                logger.debug("Extracting posts from page %s", i)
+                for post_element in page:
+                    post = extract_post_fn(post_element, options=options, request_fn=self.get)
+                    if remove_source:
+                        post.pop('source', None)
+                    yield post
